@@ -14,13 +14,12 @@
  *
  *  You should have received a copy of the GNU General Public License
  *  along with this program; if not, write to the Free Software
- *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
+ *  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  */
 
 #include "coreaudio.h"
-#include <audacious/configdb.h>
 #include <CoreAudio/CoreAudio.h>
-
+#include <audacious/plugin.h>
 #include <audacious/i18n.h>
 
 static GtkWidget *configure_win = NULL;
@@ -31,7 +30,7 @@ static gint audio_device, mixer_device;
 
 static void configure_win_ok_cb(GtkWidget * w, gpointer data)
 {
-	ConfigDb *cfgfile;
+	mcs_handle_t *cfgfile;
 
 	osx_cfg.audio_device = audio_device;
 	osx_cfg.mixer_device = mixer_device;
