@@ -13,39 +13,35 @@
  *
  *  You should have received a copy of the GNU General Public License
  *  along with this program; if not, write to the Free Software
- *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
+ *  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  */
 #include <glib.h>
-#include <glib/gi18n.h>
 
 #include "coreaudio.h"
 
-#include "audacious/plugin.h"
+#include <audacious/plugin.h>
+#include <audacious/i18n.h>
 
 OutputPlugin osx_op =
-	{
-		NULL,
-		NULL,
-		NULL, /* Description */
-		osx_init,
-		NULL,
-		osx_about,
-		osx_configure,
-		osx_get_volume,
-		osx_set_volume,
-		osx_open,
-		osx_write,
-		osx_close,
-		osx_flush,
-		osx_pause,
-		osx_free,
-		osx_playing,
-		osx_get_output_time,
-		osx_get_written_time,
-	};
-
-OutputPlugin *get_oplugin_info(void)
 {
-	osx_op.description = g_strdup(_("CoreAudio Output Plugin"));
-	return &osx_op;
-}
+	.description = "CoreAudio Output Plugin", /* Description */
+	.init = osx_init,
+	.about = osx_about,
+	.configure = osx_configure,
+	.get_volume = osx_get_volume,
+	.set_volume = osx_set_volume,
+	.open_audio = osx_open,
+	.write_audio = osx_write,
+	.close_audio = osx_close,
+	.flush = osx_flush,
+	.pause = osx_pause,
+	.buffer_free = osx_free,
+	.buffer_playing = osx_playing,
+	.output_time = osx_get_output_time,
+	.written_time = osx_get_written_time,
+	.probe_priority = 1,
+};
+
+OutputPlugin *coreaudio_oplist[] = { &osx_op, NULL };
+
+DECLARE_PLUGIN(coreaudio, NULL, NULL, NULL, coreaudio_oplist, NULL, NULL, NULL, NULL);
