@@ -331,7 +331,7 @@ void i_configure_gui_tab_ap( GtkWidget * ap_page_alignment ,
                         _("* Transpose function *\n"
                         "This option allows you to play the midi file transposed in a different key, "
                         "by shifting of the desired number of semitones all its notes (excepting those "
-                        "on midi channel 10, reserved for percussions). Expecially useful if you wish "
+                        "on midi channel 10, reserved for percussions). Especially useful if you wish "
                         "to sing or play along with another instrument.") , "" );
   gtk_tooltips_set_tip( GTK_TOOLTIPS(tips) , settplay_drumshift_spinbt ,
                         _("* Drumshift function *\n"
@@ -372,7 +372,7 @@ void i_configure_gui_tablabel_ap( GtkWidget * ap_page_alignment ,
   pagelabel_image_pix = gdk_pixbuf_new_from_xpm_data( (const gchar **)amidi_plug_icon_xpm );
   pagelabel_image = gtk_image_new_from_pixbuf( pagelabel_image_pix ); g_object_unref( pagelabel_image_pix );
   pagelabel_label = gtk_label_new( "" );
-  gtk_label_set_markup( GTK_LABEL(pagelabel_label) , "<span size=\"smaller\">AMIDI\nPlug</span>" );
+  gtk_label_set_markup( GTK_LABEL(pagelabel_label) , _("<span size=\"smaller\">AMIDI\nPlug</span>") );
   gtk_label_set_justify( GTK_LABEL(pagelabel_label) , GTK_JUSTIFY_CENTER );
   gtk_box_pack_start( GTK_BOX(pagelabel_vbox) , pagelabel_image , FALSE , FALSE , 1 );
   gtk_box_pack_start( GTK_BOX(pagelabel_vbox) , pagelabel_label , FALSE , FALSE , 1 );
