@@ -402,8 +402,8 @@ void Snes_Spc::cpu_write_high( int data, int i, rel_time_t time )
 	}
 	else
 	{
-		assert( RAM [i + rom_addr] == (uint8_t) data );
-		RAM [i + rom_addr] = cpu_pad_fill; // restore overwritten padding
+		assert( RAM [i + rom_addr - 0x10000] == (uint8_t) data );
+		RAM [i + rom_addr - 0x10000] = cpu_pad_fill; // restore overwritten padding
 		cpu_write( data, i + rom_addr - 0x10000, time );
 	}
 }
