@@ -20,6 +20,14 @@
  *  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  */
 
+#include <audacious/configdb.h>
+#include <audacious/misc.h>
+#include <audacious/playlist.h>
+#include <libaudcore/audstrings.h>
+#include <libaudcore/tuple_formatter.h>
+#include <libaudgui/libaudgui.h>
+#include <libaudgui/libaudgui-gtk.h>
+
 #include "filewriter.h"
 #include "plugins.h"
 #include "convert.h"
@@ -48,7 +56,7 @@ enum fileext_t
 };
 
 static gint fileext = WAV;
-static gchar *fileext_str[] =
+static const gchar *fileext_str[FILEEXT_MAX] =
 {
     "wav",
 #ifdef FILEWRITER_MP3
@@ -79,21 +87,20 @@ static gboolean prependnumber = FALSE;
 static gchar *file_path = NULL;
 
 VFSFile *output_file = NULL;
-guint64 offset = 0;
-Tuple *tuple = NULL;
+const Tuple *tuple = NULL;
+
+static gint64 samples_written;
 
 static OutputPluginInitStatus file_init(void);
 static void file_about(void);
-static gint file_open(AFormat fmt, gint rate, gint nch);
+static gint file_open(gint fmt, gint rate, gint nch);
 static void file_write(void *ptr, gint length);
 static gint file_write_output(void *ptr, gint length);
 static void file_close(void);
 static void file_flush(gint time);
 static void file_pause(short p);
-static gint file_free(void);
 static gint file_playing(void);
-static gint file_get_written_time(void);
-static gint file_get_output_time(void);
+static gint file_get_time (void);
 static void file_configure(void);
 
 OutputPlugin file_op =
@@ -108,15 +115,14 @@ OutputPlugin file_op =
     .close_audio = file_close,
     .flush = file_flush,
     .pause = file_pause,
-    .buffer_free = file_free,
     .buffer_playing = file_playing,
-    .output_time = file_get_output_time,
-    .written_time = file_get_written_time
+    .output_time = file_get_time,
+    .written_time = file_get_time,
 };
 
 OutputPlugin *file_oplist[] = { &file_op, NULL };
 
-SIMPLE_OUTPUT_PLUGIN(filewriter, file_oplist);
+SIMPLE_OUTPUT_PLUGIN (filewriter, file_oplist)
 
 FileWriter *plugins[FILEEXT_MAX] = {
     &wav_plugin,
@@ -141,7 +147,7 @@ static void set_plugin(void)
 
 static OutputPluginInitStatus file_init(void)
 {
-    ConfigDb *db;
+    mcs_handle_t *db;
 
     db = aud_cfg_db_open();
     aud_cfg_db_get_int(db, FILEWRITER_CFGID, "fileext", &fileext);
@@ -152,132 +158,169 @@ static OutputPluginInitStatus file_init(void)
     aud_cfg_db_get_bool(db, FILEWRITER_CFGID, "prependnumber", &prependnumber);
     aud_cfg_db_close(db);
 
-    if (!file_path)
-        file_path = g_strdup(g_get_home_dir());
+    if (file_path == NULL)
+    {
+        g_return_val_if_fail (getenv ("HOME") != NULL, OUTPUT_PLUGIN_INIT_FAIL);
+        file_path = g_filename_to_uri (getenv ("HOME"), NULL, NULL);
+        g_return_val_if_fail (file_path != NULL, OUTPUT_PLUGIN_INIT_FAIL);
+    }
 
     set_plugin();
     if (plugin->init)
         plugin->init(&file_write_output);
 
-    return OUTPUT_PLUGIN_INIT_NO_DEVICES;
+    return OUTPUT_PLUGIN_INIT_FOUND_DEVICES;
 }
 
-void file_about(void)
+void file_about (void)
 {
-    static GtkWidget *dialog;
+    static GtkWidget * dialog;
 
-    if (dialog != NULL)
-        return;
-
-    dialog = audacious_info_dialog(_("About FileWriter-Plugin"),
-                               _("FileWriter-Plugin\n\n"
-                               "This program is free software; you can redistribute it and/or modify\n"
-                               "it under the terms of the GNU General Public License as published by\n"
-                               "the Free Software Foundation; either version 2 of the License, or\n"
-                               "(at your option) any later version.\n"
-                               "\n"
-                               "This program is distributed in the hope that it will be useful,\n"
-                               "but WITHOUT ANY WARRANTY; without even the implied warranty of\n"
-                               "MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the\n"
-                               "GNU General Public License for more details.\n"
-                               "\n"
-                               "You should have received a copy of the GNU General Public License\n"
-                               "along with this program; if not, write to the Free Software\n"
-                               "Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301,\n"
-                               "USA."), _("Ok"), FALSE, NULL, NULL);
-    gtk_signal_connect(GTK_OBJECT(dialog), "destroy",
-                       GTK_SIGNAL_FUNC(gtk_widget_destroyed), &dialog);
+    audgui_simple_message (& dialog, GTK_MESSAGE_INFO,
+     _("About FileWriter-Plugin"),
+     _("FileWriter-Plugin\n\n"
+     "This program is free software; you can redistribute it and/or modify\n"
+     "it under the terms of the GNU General Public License as published by\n"
+     "the Free Software Foundation; either version 2 of the License, or\n"
+     "(at your option) any later version.\n"
+     "\n"
+     "This program is distributed in the hope that it will be useful,\n"
+     "but WITHOUT ANY WARRANTY; without even the implied warranty of\n"
+     "MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the\n"
+     "GNU General Public License for more details.\n"
+     "\n"
+     "You should have received a copy of the GNU General Public License\n"
+     "along with this program; if not, write to the Free Software\n"
+     "Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301,\n"
+     "USA."));
 }
 
-static gint file_open(AFormat fmt, gint rate, gint nch)
+static VFSFile * safe_create (const gchar * filename)
+{
+    if (! vfs_file_test (filename, G_FILE_TEST_EXISTS))
+        return vfs_fopen (filename, "w");
+
+    const gchar * extension = strrchr (filename, '.');
+    gint length = strlen (filename);
+    gchar scratch[length + 3];
+    gint count;
+
+    for (count = 1; count < 100; count ++)
+    {
+        if (extension == NULL)
+            sprintf (scratch, "%s-%d", filename, count);
+        else
+            sprintf (scratch, "%.*s-%d%s", (gint) (extension - filename),
+             filename, count, extension);
+
+        if (! vfs_file_test (scratch, G_FILE_TEST_EXISTS))
+            return vfs_fopen (scratch, "w");
+    }
+
+    return NULL;
+}
+
+static gint file_open(gint fmt, gint rate, gint nch)
 {
     gchar *filename = NULL, *temp = NULL;
-    const gchar *directory;
+    gchar * directory;
     gint pos;
     gint rv;
-    Playlist *playlist;
+    gint playlist;
 
     input.format = fmt;
     input.frequency = rate;
     input.channels = nch;
 
-    playlist = aud_playlist_get_active();
-    if(!playlist)
+    playlist = aud_playlist_get_playing ();
+    if (playlist < 0)
         return 0;
 
     pos = aud_playlist_get_position(playlist);
-    tuple = aud_playlist_get_tuple(playlist, pos);
-    if(!tuple)
+    tuple = aud_playlist_entry_get_tuple (playlist, pos, FALSE);
+    if (tuple == NULL)
         return 0;
 
     if (filenamefromtags)
     {
-        gchar *utf8 = aud_tuple_formatter_make_title_string(tuple, aud_get_gentitle_format());
+        gchar *utf8 = tuple_formatter_make_title_string(tuple, aud_get_gentitle_format());
 
-        g_strchomp(utf8); /* chop trailing ^J --yaz */
-
-        filename = g_locale_from_utf8(utf8, -1, NULL, NULL, NULL);
-        g_free(utf8);
-        while (filename != NULL && (temp = strchr(filename, '/')) != NULL)
-            *temp = '-';
+        string_replace_char (utf8, '/', ' ');
+        filename = string_encode_percent (utf8, FALSE);
+        g_free (utf8);
     }
-    if (filename == NULL)
+    else
     {
-        filename = g_strdup(aud_tuple_get_string(tuple, FIELD_FILE_NAME, NULL));
+        const gchar * original = strrchr (aud_playlist_entry_get_filename
+         (playlist, pos), '/');
+
+        g_return_val_if_fail (original != NULL, 0);
+        filename = g_strdup (original + 1);
+
         if (!use_suffix)
             if ((temp = strrchr(filename, '.')) != NULL)
                 *temp = '\0';
     }
-    if (filename == NULL)
-        filename = g_strdup_printf("aud-%d", pos);
-
 
     if (prependnumber)
     {
-        gint number = aud_tuple_get_int(tuple, FIELD_TRACK_NUMBER, NULL);
+        gint number = tuple_get_int(tuple, FIELD_TRACK_NUMBER, NULL);
         if (!tuple || !number)
             number = pos + 1;
 
-        temp = g_strdup_printf("%.02d %s", number, filename);
+        temp = g_strdup_printf ("%d%%20%s", number, filename);
         g_free(filename);
         filename = temp;
     }
 
     if (save_original)
-        directory = aud_tuple_get_string(tuple, FIELD_FILE_PATH, NULL);
+    {
+        directory = g_strdup (aud_playlist_entry_get_filename (playlist, pos));
+        temp = strrchr (directory, '/');
+        g_return_val_if_fail (temp != NULL, 0);
+        temp[1] = 0;
+    }
     else
-        directory = file_path;
+    {
+        g_return_val_if_fail (file_path[0], 0);
+        if (file_path[strlen (file_path) - 1] == '/')
+            directory = g_strdup (file_path);
+        else
+            directory = g_strdup_printf ("%s/", file_path);
+    }
 
-    temp = g_strdup_printf("file://%s/%s.%s",
-                           directory, filename, fileext_str[fileext]);
-    g_free(filename);
+    temp = g_strdup_printf ("%s%s.%s", directory, filename, fileext_str[fileext]);
+    g_free (directory);
+    g_free (filename);
     filename = temp;
 
-    output_file = aud_vfs_fopen(filename, "w");
-    g_free(filename);
+    output_file = safe_create (filename);
+    g_free (filename);
 
-    if (!output_file)
+    if (output_file == NULL)
         return 0;
 
     convert_init(fmt, plugin->format_required, nch);
 
     rv = (plugin->open)();
 
+    samples_written = 0;
+
     return rv;
 }
 
 static void file_write(void *ptr, gint length)
 {
-    int len;
-
-    len = convert_process(ptr, length);
+    int len = convert_process (ptr, length);
 
     plugin->write(convert_output, len);
+
+    samples_written += length / FMT_SIZEOF (input.format);
 }
 
 static gint file_write_output(void *ptr, gint length)
 {
-    return aud_vfs_fwrite(ptr, 1, length, output_file);
+    return vfs_fwrite(ptr, 1, length, output_file);
 }
 
 static void file_close(void)
@@ -285,56 +328,41 @@ static void file_close(void)
     plugin->close();
     convert_free();
 
-    if (output_file)
-    {
-        aud_vfs_fclose(output_file);
-    }
+    if (output_file != NULL)
+        vfs_fclose(output_file);
     output_file = NULL;
 }
 
 static void file_flush(gint time)
 {
-    if (time < 0)
-        return;
-
     file_close();
     file_open(input.format, input.frequency, input.channels);
 
-    offset = time;
+    samples_written = time * (gint64) input.channels * input.frequency / 1000;
 }
 
 static void file_pause(short p)
 {
 }
 
-static gint file_free(void)
-{
-    return plugin->free();
-}
-
 static gint file_playing(void)
 {
-    return plugin->playing();
+    return 0;
 }
 
-static gint file_get_written_time(void)
+static gint file_get_time (void)
 {
-    return plugin->get_written_time();
-}
-
-static gint file_get_output_time(void)
-{
-    return file_get_written_time();
+    return samples_written * 1000 / (input.channels * input.frequency);
 }
 
 static void configure_ok_cb(gpointer data)
 {
-    ConfigDb *db;
+    mcs_handle_t *db;
 
     fileext = gtk_combo_box_get_active(GTK_COMBO_BOX(fileext_combo));
 
-    g_free(file_path);
-    file_path = g_strdup(gtk_file_chooser_get_current_folder(GTK_FILE_CHOOSER(path_dirbrowser)));
+    g_free (file_path);
+    file_path = gtk_file_chooser_get_uri ((GtkFileChooser *) path_dirbrowser);
 
     use_suffix =
         gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(use_suffix_toggle));
@@ -426,6 +454,7 @@ static void file_configure(void)
     if (!configure_win)
     {
         configure_win = gtk_window_new(GTK_WINDOW_TOPLEVEL);
+        gtk_window_set_type_hint(GTK_WINDOW(configure_win), GDK_WINDOW_TYPE_HINT_DIALOG);
 
         gtk_signal_connect(GTK_OBJECT(configure_win), "destroy",
                            GTK_SIGNAL_FUNC(configure_destroy), NULL);
@@ -502,8 +531,7 @@ static void file_configure(void)
         path_dirbrowser =
             gtk_file_chooser_button_new (_("Pick a folder"),
                                          GTK_FILE_CHOOSER_ACTION_SELECT_FOLDER);
-        gtk_file_chooser_set_current_folder(GTK_FILE_CHOOSER(path_dirbrowser),
-                                            file_path);
+        gtk_file_chooser_set_uri ((GtkFileChooser *) path_dirbrowser, file_path);
         gtk_box_pack_start(GTK_BOX(path_hbox), path_dirbrowser, TRUE, TRUE, 0);
 
         if (save_original)
