@@ -140,7 +140,9 @@ static GtkActionEntry action_entries_playlist[] = {
  {"playlist sort path", NULL, N_("By File Path"), NULL, NULL, (GCallback)
   playlist_sort_path},
  {"playlist reverse", GTK_STOCK_SORT_DESCENDING, N_("Reverse Order"), NULL,
-  NULL, (GCallback) playlist_reverse}};
+  NULL, (GCallback) playlist_reverse},
+ {"playlist randomize", NULL, N_("Random Order"), NULL, NULL, (GCallback)
+  playlist_randomize}};
 
 static GtkActionEntry action_entries_output[] =
 {
