@@ -30,7 +30,7 @@
  *
  *  You should have received a copy of the GNU General Public License
  *  along with audacious-hotkey; if not, write to the Free Software
- *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
+ *  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  */
 
 #include <config.h>
@@ -39,8 +39,10 @@
 #include <gdk/gdkx.h>
 #include <gdk/gdkkeysyms.h>
 
+#include <audacious/plugin.h>
 #include <audacious/i18n.h>
-#include <audacious/util.h>
+#include <libaudgui/libaudgui.h>
+#include <libaudgui/libaudgui-gtk.h>
 
 #include "plugin.h"
 #include "gui.h"
@@ -621,7 +623,7 @@ void ok_callback (GtkWidget *widget, gpointer data)
 		HotkeyConfiguration * old;
 		old = hotkey;
 		hotkey = hotkey->next;
-		free(old);
+		g_free(old);
 	}
 	plugin_cfg->first.next = NULL;
 	plugin_cfg->first.key = 0;
@@ -633,8 +635,7 @@ void ok_callback (GtkWidget *widget, gpointer data)
 	{
 		if (controls->hotkey.key) {
 			if (hotkey->key) {
-				hotkey->next = (HotkeyConfiguration*)
-					malloc(sizeof (HotkeyConfiguration));
+				hotkey->next = g_new(HotkeyConfiguration, 1);
 				hotkey = hotkey->next;
 				hotkey->next = NULL;
 			}
@@ -651,25 +652,19 @@ void ok_callback (GtkWidget *widget, gpointer data)
 	gtk_widget_destroy (gtk_widget_get_toplevel (GTK_WIDGET (widget)));
 }
 
-
-
 void show_about (void)
 {
-	static GtkWidget *dialog;
+    static GtkWidget * dialog = NULL;
 
-	dialog = audacious_info_dialog (_("About Global Hotkey Plugin"),
-				_("Global Hotkey Plugin\n"
-				"Control the player with global key combinations or multimedia keys.\n\n"
-				"Copyright (C) 2007-2008 Sascha Hlusiak <contact@saschahlusiak.de>\n\n"
-				"Contributers include:\n"
-				"Copyright (C) 2006-2007 Vladimir Paskov <vlado.paskov@gmail.com>\n"
-				"Copyright (C) 2000-2002 Ville Syrjälä <syrjala@sci.fi>\n"
-                         	"			Bryn Davies <curious@ihug.com.au>\n"
-                        	"			Jonathan A. Davis <davis@jdhouse.org>\n"
-                         	"			Jeremy Tan <nsx@nsx.homeip.net>\n\n"
-                         	),
-                         	_("OK"), TRUE, NULL, NULL);
-
-	gtk_signal_connect(GTK_OBJECT(dialog), "destroy",
-			   GTK_SIGNAL_FUNC(gtk_widget_destroyed), &dialog);
+    audgui_simple_message (& dialog, GTK_MESSAGE_INFO,
+     _("About Global Hotkey Plugin"),
+     _("Global Hotkey Plugin\n"
+     "Control the player with global key combinations or multimedia keys.\n\n"
+     "Copyright (C) 2007-2008 Sascha Hlusiak <contact@saschahlusiak.de>\n\n"
+     "Contributers include:\n"
+     "Copyright (C) 2006-2007 Vladimir Paskov <vlado.paskov@gmail.com>\n"
+     "Copyright (C) 2000-2002 Ville Syrjälä <syrjala@sci.fi>\n"
+     "			Bryn Davies <curious@ihug.com.au>\n"
+     "			Jonathan A. Davis <davis@jdhouse.org>\n"
+     "			Jeremy Tan <nsx@nsx.homeip.net>\n\n"));
 }
