@@ -1,7 +1,7 @@
 /*
  * Audacious: A cross-platform multimedia player
- * Copyright (c) 2006 William Pitcock, Tony Vroon, George Averill,
- *                    Giacomo Lozito, Derek Pomery and Yoshiki Yazawa.
+ * Copyright (c) 2006-2010 William Pitcock, Tony Vroon, George Averill, Giacomo
+ *  Lozito, Derek Pomery and Yoshiki Yazawa, and John Lindgren.
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -18,135 +18,98 @@
  * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  */
 
-/* #define AUD_DEBUG 1 */
-
 #include <glib.h>
 #include <string.h>
-#include <glib.h>
-#include <glib/gprintf.h>
 #include <stdlib.h>
-#include <string.h>
-#include <time.h>
 
-#include <unistd.h>
-#include <sys/types.h>
-#include <sys/stat.h>
-#include <sys/errno.h>
-
-#include <audacious/debug.h>
 #include <audacious/misc.h>
 #include <audacious/playlist.h>
 #include <audacious/plugin.h>
 #include <libaudcore/audstrings.h>
 
-static void
-parse_extm3u_info(const gchar * info, gchar ** title, gint * length)
+static void strip_char (gchar * text, gchar c)
 {
-    gchar *str;
-    gchar *temp;
+    gchar * set = text;
+    gchar a;
 
-    g_return_if_fail(info != NULL);
-    g_return_if_fail(title != NULL);
-    g_return_if_fail(length != NULL);
-
-    *title = NULL;
-    *length = -1;
-
-    if (!str_has_prefix_nocase(info, "#EXTINF:")) {
-        g_message("Invalid m3u metadata (%s)", info);
-        return;
+    while ((a = * text ++))
+    {
+        if (a != c)
+            * set ++ = a;
     }
 
-    info += 8;
-
-    *length = atoi(info);
-    if (*length <= 0)
-        *length = -1;
-    else
-        *length *= 1000;
-
-    if ((str = strchr(info, ','))) {
-        temp = g_strstrip(g_strdup(str + 1));
-        if (strlen(temp) > 0)
-        	*title = g_locale_to_utf8(temp, -1, NULL, NULL, NULL);
-
-        g_free(temp);
-        temp = NULL;
-    }
+    * set = 0;
 }
 
-static void
-playlist_load_m3u(const gchar * filename, gint pos)
+static gchar * read_win_text (const gchar * path)
 {
-    struct index * add;
-    VFSFile *file;
-    gchar *line;
-    gchar *ext_info = NULL, *ext_title = NULL;
-    gsize line_len = 1024;
-    gint ext_len = -1;
-    gboolean is_extm3u = FALSE;
-    gchar *uri = NULL;
+    void * raw;
+    gint64 size;
 
-    uri = g_filename_to_uri(filename, NULL, NULL);
+    vfs_file_get_contents (path, & raw, & size);
 
-    if ((file = vfs_fopen(uri ? uri : filename, "rb")) == NULL)
+    if (raw == NULL)
+        return NULL;
+
+    gchar * text = g_convert (raw, size, "UTF-8", "ISO-8859-1", NULL, NULL, NULL);
+    g_free (raw);
+    strip_char (text, '\r');
+    return text;
+}
+
+static gchar * split_line (gchar * line)
+{
+    gchar * feed = strchr (line, '\n');
+
+    if (feed == NULL)
+        return NULL;
+
+    * feed = 0;
+    return feed + 1;
+}
+
+static gchar * convert_path (gchar * path, const gchar * base)
+{
+    if (strstr (path, "://") != NULL)
+        return g_strdup (path);
+
+    return aud_construct_uri (path, base);
+}
+
+static void playlist_load_m3u (const gchar * path, gint at)
+{
+    gchar * text = read_win_text (path);
+
+    if (text == NULL)
         return;
 
-    g_free(uri); uri = NULL;
+    gchar * parse = text;
+    struct index * add = index_new ();
 
-    add = index_new ();
+    while (1)
+    {
+        gchar * next = split_line (parse);
 
-    line = g_malloc(line_len);
-    while (vfs_fgets(line, line_len, file)) {
-        while (strlen(line) == line_len - 1 && line[strlen(line) - 1] != '\n') {
-            line_len += 1024;
-            line = g_realloc(line, line_len);
-            vfs_fgets(&line[strlen(line)], 1024, file);
-        }
+        while (* parse == ' ' || * parse == '\t')
+            parse ++;
 
-        while (line[strlen(line) - 1] == '\r' ||
-               line[strlen(line) - 1] == '\n')
-            line[strlen(line) - 1] = '\0';
+        if (! * parse)
+            break;
 
-        if (str_has_prefix_nocase(line, "#EXTM3U")) {
-            is_extm3u = TRUE;
-            continue;
-        }
+        if (* parse == '#')
+            goto NEXT;
 
-        if (is_extm3u && str_has_prefix_nocase(line, "#EXTINF:")) {
-            str_replace_in(&ext_info, g_strdup(line));
-            continue;
-        }
+        gchar * s = convert_path (parse, path);
 
-        if (line[0] == '#' || strlen(line) == 0) {
-            if (ext_info) {
-                g_free(ext_info);
-                ext_info = NULL;
-            }
-            continue;
-        }
+        if (s != NULL)
+            index_append (add, s);
 
-        if (is_extm3u) {
-            if (ext_info)
-                parse_extm3u_info(ext_info, &ext_title, &ext_len);
-            g_free(ext_info);
-            ext_info = NULL;
-        }
-
-        uri = aud_construct_uri(line, filename);
-        AUDDBG("uri=%s\n", uri);
-
-        if (uri != NULL)
-            index_append (add, uri);
-
-        str_replace_in(&ext_title, NULL);
-        ext_len = -1;
+NEXT:
+        parse = next;
     }
 
-    vfs_fclose(file);
-    g_free(line);
-
-    aud_playlist_entry_insert_batch (aud_playlist_get_active (), pos, add, NULL);
+    aud_playlist_entry_insert_batch (aud_playlist_get_active (), at, add, NULL);
+    g_free (text);
 }
 
 static void
