@@ -1,11 +1,15 @@
 #ifndef NET_H
 #define NET_H 1
 
-#include "audacious/titlestring.h"
+#include <libaudcore/tuple.h>
+
+#define SC_CURL_TIMEOUT 60
+
+gboolean sc_timeout(gpointer data);
 
 int sc_idle(GMutex *);
-void sc_init(char *, char *);
-void sc_addentry(GMutex *, TitleInput *, int);
+void sc_init(char *, char *, char *);
+void sc_addentry(GMutex *, Tuple *, int);
 void sc_cleaner(void);
 int sc_catch_error(void);
 char *sc_fetch_error(void);
