@@ -25,14 +25,11 @@
 
 /*#define AUD_DEBUG*/
 
-#ifdef HAVE_CONFIG_H
-#  include "config.h"
-#endif
+#include "config.h"
 
 #include "ui_equalizer.h"
 
 #include <glib.h>
-#include <glib/gi18n.h>
 #include <gtk/gtk.h>
 #include <stdio.h>
 #include <math.h>
@@ -45,8 +42,14 @@
 #include "util.h"
 #include "ui_main.h"
 #include "ui_playlist.h"
-#include <audacious/plugin.h>
-#include <audacious/equalizer_preset.h>
+
+#include <audacious/audconfig.h>
+#include <audacious/drct.h>
+#include <audacious/i18n.h>
+#include <audacious/misc.h>
+#include <audacious/playlist.h>
+#include <libaudcore/hook.h>
+#include <libaudgui/libaudgui-gtk.h>
 
 #include "images/audacious_eq.xpm"
 
@@ -127,12 +130,11 @@ equalizerwin_set_scaled(gboolean ds)
     else
         height = 116;
 
-    if (config.scaled) {
-        dock_window_resize(GTK_WINDOW(equalizerwin), 275 * config.scale_factor,
-            height * config.scale_factor);
-    } else {
-        dock_window_resize(GTK_WINDOW(equalizerwin), 275, height);
-    }
+    if (config.scaled)
+        resize_window(equalizerwin, 275 * config.scale_factor, height *
+         config.scale_factor);
+    else
+        resize_window(equalizerwin, 275, height);
 
     skinned = (SkinnedWindow *) equalizerwin;
     fixed = (GtkFixed *) skinned->normal;
@@ -194,7 +196,7 @@ equalizerwin_eq_changed(void)
     for (i = 0; i < AUD_EQUALIZER_NBANDS; i++)
         aud_cfg->equalizer_bands[i] = equalizerwin_get_band(i);
 
-    aud_hook_call("equalizer changed", NULL);
+    hook_call("equalizer changed", NULL);
 }
 
 static void
@@ -216,6 +218,18 @@ equalizerwin_on_pushed(void)
     equalizerwin_activate(!aud_cfg->equalizer_active);
 }
 
+static void
+update_from_config(void *unused1, void *unused2)
+{
+    gint i;
+
+    ui_skinned_button_set_inside(equalizerwin_on, aud_cfg->equalizer_active);
+    ui_skinned_equalizer_slider_set_position(equalizerwin_preamp, aud_cfg->equalizer_preamp);
+    for (i = 0; i < AUD_EQUALIZER_NBANDS; i++)
+        ui_skinned_equalizer_slider_set_position(equalizerwin_bands[i], aud_cfg->equalizer_bands[i]);
+    ui_skinned_equalizer_graph_update(equalizerwin_graph);
+}
+
 static void
 equalizerwin_presets_pushed(void)
 {
@@ -223,7 +237,8 @@ equalizerwin_presets_pushed(void)
     gint x, y;
 
     gdk_window_get_pointer(NULL, &x, &y, &modmask);
-    ui_manager_popup_menu_show(GTK_MENU(equalizerwin_presets_menu), x, y, 1, GDK_CURRENT_TIME);
+    ui_popup_menu_show(UI_MENU_EQUALIZER_PRESET, x, y, FALSE, FALSE, 1,
+     GDK_CURRENT_TIME);
 }
 
 static void
@@ -232,6 +247,16 @@ equalizerwin_auto_pushed(void)
     aud_cfg->equalizer_autoload = UI_SKINNED_BUTTON(equalizerwin_auto)->inside;
 }
 
+static GtkWidget * get_eq_effects_menu (void)
+{
+    static GtkWidget * menu = NULL;
+
+    if (menu == NULL)
+        menu = audgui_create_effects_menu ();
+
+    return menu;
+}
+
 gboolean
 equalizerwin_press(GtkWidget * widget, GdkEventButton * event,
                    gpointer callback_data)
@@ -243,14 +268,12 @@ equalizerwin_press(GtkWidget * widget, GdkEventButton * event,
             dock_move_release(GTK_WINDOW(equalizerwin));
         return TRUE;
     }
-    if (event->button == 3) {
-        /*
-         * Pop up the main menu a few pixels down to avoid
-         * anything to be selected initially.
-         */
-       ui_manager_popup_menu_show(GTK_MENU(mainwin_general_menu), event->x_root,
-                                event->y_root + 2, 3, event->time);
-       return TRUE;
+
+    if (event->button == 3)
+    {
+        gtk_menu_popup ((GtkMenu *) get_eq_effects_menu (), NULL, NULL, NULL,
+         NULL, 3, event->time);
+        return TRUE;
     }
 
     return FALSE;
@@ -262,11 +285,13 @@ equalizerwin_close_cb(void)
     equalizerwin_show(FALSE);
 }
 
-static gboolean
-equalizerwin_delete(GtkWidget * widget,
-                    gpointer data)
+static gboolean equalizerwin_delete(GtkWidget *widget, void *data)
 {
-    equalizerwin_show(FALSE);
+    if (config.show_wm_decorations)
+        equalizerwin_show(FALSE);
+    else
+        aud_drct_quit();
+
     return TRUE;
 }
 
@@ -434,7 +459,7 @@ equalizerwin_create_window(void)
     width = 275;
     height = config.equalizer_shaded ? 14 : 116;
 
-    equalizerwin = ui_skinned_window_new("equalizer");
+    equalizerwin = ui_skinned_window_new("equalizer", &config.equalizer_x, &config.equalizer_y);
     gtk_window_set_title(GTK_WINDOW(equalizerwin), _("Audacious Equalizer"));
     gtk_window_set_role(GTK_WINDOW(equalizerwin), "equalizer");
     gtk_window_set_resizable(GTK_WINDOW(equalizerwin), FALSE);
@@ -457,10 +482,6 @@ equalizerwin_create_window(void)
 
     gtk_widget_set_app_paintable(equalizerwin, TRUE);
 
-    if (config.save_window_position)
-        gtk_window_move(GTK_WINDOW(equalizerwin),
-                        config.equalizer_x, config.equalizer_y);
-
     g_signal_connect(equalizerwin, "delete_event",
                      G_CALLBACK(equalizerwin_delete), NULL);
     g_signal_connect(equalizerwin, "button_press_event",
@@ -480,6 +501,11 @@ equalizerwin_create(void)
     gtk_window_add_accel_group( GTK_WINDOW(equalizerwin) , ui_manager_get_accel_group() );
 
     equalizerwin_create_widgets();
+
+    hook_associate("equalizer changed", (HookFunction) update_from_config, NULL);
+
+    gtk_widget_show_all (((SkinnedWindow *) equalizerwin)->normal);
+    gtk_widget_show_all (((SkinnedWindow *) equalizerwin)->shaded);
 }
 
 static void equalizerwin_real_show (void)
@@ -491,17 +517,12 @@ static void equalizerwin_real_show (void)
         gtk_widget_set_size_request(equalizerwin, 275,
                                     (config.equalizer_shaded ? 14 : 116));
     ui_skinned_button_set_inside(mainwin_eq, TRUE);
-    gtk_widget_show_all(equalizerwin);
 
     gtk_window_present(GTK_WINDOW(equalizerwin));
 }
 
 static void equalizerwin_real_hide (void)
 {
-    if (config.save_window_position)
-        gtk_window_get_position ((GtkWindow *) equalizerwin,
-         & config.equalizer_x, & config.equalizer_y);
-
     gtk_widget_hide(equalizerwin);
     ui_skinned_button_set_inside(mainwin_eq, FALSE);
 }
@@ -517,8 +538,11 @@ equalizerwin_show(gboolean show)
         gtk_toggle_action_set_active (GTK_TOGGLE_ACTION (a), show);
     else
     {
-        config.equalizer_visible = show;
-        aud_cfg->equalizer_visible = show;
+        if (show != config.equalizer_visible) {
+            config.equalizer_visible = show;
+            config.equalizer_visible_prev = !show;
+            aud_cfg->equalizer_visible = show;
+        }
 
         if (show)
            equalizerwin_real_show ();
@@ -673,14 +697,16 @@ equalizerwin_read_winamp_eqf(VFSFile * file)
     equalizerwin_eq_changed();
 }
 
-static void
-equalizerwin_read_aud_preset(const gchar * file)
+static gboolean equalizerwin_read_aud_preset (const gchar * file)
 {
-    EqualizerPreset *preset = aud_equalizer_read_aud_preset(file);
-    if (preset) {
-        equalizerwin_apply_preset(preset);
-        equalizer_preset_free(preset);
-    }
+    EqualizerPreset * preset = aud_load_preset_file (file);
+
+    if (preset == NULL)
+        return FALSE;
+
+    equalizerwin_apply_preset (preset);
+    equalizer_preset_free (preset);
+    return TRUE;
 }
 
 static void
@@ -832,7 +858,7 @@ open_vfs_file(const gchar *filename, const gchar *mode)
     VFSFile *file;
     GtkWidget *dialog;
 
-    if (!(file = aud_vfs_fopen(filename, mode))) {
+    if (!(file = vfs_fopen(filename, mode))) {
         dialog = gtk_message_dialog_new (GTK_WINDOW (mainwin),
                                          GTK_DIALOG_DESTROY_WITH_PARENT,
                                          GTK_MESSAGE_ERROR,
@@ -855,7 +881,7 @@ load_winamp_file(const gchar * filename)
         return;
 
     equalizerwin_read_winamp_eqf(file);
-    aud_vfs_fclose(file);
+    vfs_fclose(file);
 }
 
 static void
@@ -871,11 +897,10 @@ import_winamp_file(const gchar * filename)
     equalizer_presets = g_list_concat(equalizer_presets, list);
     aud_equalizer_write_preset_file(equalizer_presets, "eq.preset");
 
-    aud_vfs_fclose(file);
+    vfs_fclose(file);
 }
 
-static void
-save_winamp_file(const gchar * filename)
+static gboolean save_winamp_file (const gchar * filename)
 {
     VFSFile *file;
 
@@ -884,21 +909,31 @@ save_winamp_file(const gchar * filename)
     guchar bands[11];
 
     if (!(file = open_vfs_file(filename, "wb")))
-        return;
+        return FALSE;
 
-    aud_vfs_fwrite("Winamp EQ library file v1.1\x1a!--", 1, 31, file);
+    if (vfs_fwrite ("Winamp EQ library file v1.1\x1a!--", 1, 31, file) != 31)
+        goto ERR;
 
     memset(name, 0, 257);
     g_strlcpy(name, "Entry1", 257);
-    aud_vfs_fwrite(name, 1, 257, file);
+
+    if (vfs_fwrite (name, 1, 257, file) != 257)
+        goto ERR;
 
     for (i = 0; i < AUD_EQUALIZER_NBANDS; i++)
         bands[i] = 63 - (((equalizerwin_get_band(i) + EQUALIZER_MAX_GAIN) * 63) / EQUALIZER_MAX_GAIN / 2);
 
     bands[AUD_EQUALIZER_NBANDS] = 63 - (((equalizerwin_get_preamp() + EQUALIZER_MAX_GAIN) * 63) / EQUALIZER_MAX_GAIN / 2);
 
-    aud_vfs_fwrite(bands, 1, 11, file);
-    aud_vfs_fclose(file);
+    if (vfs_fwrite (bands, 1, 11, file) != 11)
+        goto ERR;
+
+    vfs_fclose (file);
+    return TRUE;
+
+ERR:
+    vfs_fclose (file);
+    return FALSE;
 }
 
 static GtkWidget *
@@ -1011,45 +1046,6 @@ equalizerwin_create_list_window(GList *preset_list,
     return *window;
 }
 
-void
-equalizerwin_load_auto_preset(const gchar * filename)
-{
-    gchar *presetfilename, *directory;
-
-    g_return_if_fail(filename != NULL);
-
-    if (!aud_cfg->equalizer_autoload)
-        return;
-
-    presetfilename = g_strconcat(filename, ".", aud_cfg->eqpreset_extension, NULL);
-
-    /* First try to find a per file preset file */
-    if (strlen(aud_cfg->eqpreset_extension) > 0) {
-        equalizerwin_read_aud_preset(presetfilename);
-        g_free(presetfilename);
-        return;
-    }
-
-    g_free(presetfilename);
-
-    directory = g_path_get_dirname(filename);
-    presetfilename = g_build_filename(directory, aud_cfg->eqpreset_default_file,
-                                      NULL);
-    g_free(directory);
-
-    /* Try to find a per directory preset file */
-    if (strlen(aud_cfg->eqpreset_default_file) > 0) {
-        equalizerwin_read_aud_preset(presetfilename);
-    }
-    else if (!equalizerwin_load_preset
-             (equalizer_auto_presets, g_basename(filename))) {
-        /* Fall back to the oldstyle auto presets */
-        equalizerwin_load_preset(equalizer_presets, "Default");
-    }
-
-    g_free(presetfilename);
-}
-
 void
 equalizerwin_set_preamp(gfloat preamp)
 {
@@ -1200,7 +1196,6 @@ void
 action_equ_save_auto_preset(void)
 {
     gchar *name;
-    Playlist *playlist = aud_playlist_get_active();
 
     if (equalizerwin_save_auto_window)
         gtk_window_present(GTK_WINDOW(equalizerwin_save_auto_window));
@@ -1214,8 +1209,10 @@ action_equ_save_auto_preset(void)
                                         G_CALLBACK(equalizerwin_save_auto_ok),
                                         G_CALLBACK(equalizerwin_save_auto_select));
 
-    name = aud_playlist_get_filename(playlist, aud_playlist_get_position(playlist));
-    if (name) {
+    name = aud_drct_pl_get_file (aud_drct_pl_get_pos ());
+
+    if (name != NULL)
+    {
         gtk_entry_set_text(GTK_ENTRY(equalizerwin_save_auto_entry),
                            g_basename(name));
         g_free(name);
@@ -1235,7 +1232,6 @@ action_equ_save_preset_file(void)
     GtkWidget *dialog;
     gchar *file_uri;
     gchar *songname;
-    Playlist *playlist = aud_playlist_get_active();
     gint i;
 
     dialog = make_filebrowser(Q_("Save equalizer preset"), TRUE);
@@ -1252,8 +1248,10 @@ action_equ_save_preset_file(void)
         g_free(file_uri);
     }
 
-    songname = aud_playlist_get_filename(playlist, aud_playlist_get_position(playlist));
-    if (songname) {
+    songname = aud_drct_pl_get_file (aud_drct_pl_get_pos ());
+
+    if (songname != NULL)
+    {
         gchar *eqname = g_strdup_printf("%s.%s", songname,
                                         aud_cfg->eqpreset_extension);
         g_free(songname);
@@ -1322,3 +1320,74 @@ equalizerwin_activate(gboolean active)
     ui_skinned_button_set_inside(equalizerwin_on, active);
     equalizerwin_eq_changed();
 }
+
+static void load_auto_preset (const gchar * filename)
+{
+    gchar * base;
+
+    if (aud_cfg->eqpreset_extension != NULL)
+    {
+        gchar * eq_file = g_strconcat (filename, ".",
+         aud_cfg->eqpreset_extension, NULL);
+        gboolean success = equalizerwin_read_aud_preset (eq_file);
+
+        g_free (eq_file);
+
+        if (success)
+            return;
+    }
+
+    if (aud_cfg->eqpreset_default_file != NULL)
+    {
+        gchar * folder = g_path_get_dirname (filename);
+        gchar * eq_file = g_build_filename (folder,
+         aud_cfg->eqpreset_default_file, NULL);
+        gboolean success = equalizerwin_read_aud_preset (eq_file);
+
+        g_free (folder);
+        g_free (eq_file);
+
+        if (success)
+            return;
+    }
+
+    base = g_path_get_basename (filename);
+
+    if (! equalizerwin_load_preset (equalizer_auto_presets, base))
+    {
+        if (! equalizerwin_load_preset (equalizer_presets, "Default"))
+            action_equ_zero_preset ();
+    }
+
+    g_free (base);
+}
+
+static void position_cb (void * data, void * user_data)
+{
+    gint playlist = GPOINTER_TO_INT (data);
+    gint position = aud_playlist_get_position (playlist);
+
+    if (! aud_cfg->equalizer_autoload || playlist != aud_playlist_get_playing ()
+     || position == -1)
+        return;
+
+    load_auto_preset (aud_playlist_entry_get_filename (playlist, position));
+}
+
+void eq_init_hooks (void)
+{
+    gint playlist = aud_playlist_get_playing ();
+
+    /* Load preset for the first song. FIXME: Doing this at interface load is
+     really too late as the song may already be started. Really, this stuff
+     shouldn't be in the interface plugin at all but in core. -jlindgren */
+    if (playlist != -1)
+        position_cb (GINT_TO_POINTER (playlist), NULL);
+
+    hook_associate ("playlist position", position_cb, NULL);
+}
+
+void eq_end_hooks (void)
+{
+    hook_dissociate ("playlist position", position_cb);
+}
