@@ -21,12 +21,16 @@
  * along with this program;  If not, see <http://www.gnu.org/licenses>.
  */
 
+#include "config.h"
+
+#include <audacious/i18n.h>
+
 #include "ui_skin.h"
 #include "ui_equalizer.h"
 #include "ui_main.h"
 #include "skins_cfg.h"
 #include "ui_skinned_equalizer_slider.h"
-#include <glib/gi18n.h>
+#include "util.h"
 
 #define UI_TYPE_SKINNED_EQUALIZER_SLIDER           (ui_skinned_equalizer_slider_get_type())
 #define UI_SKINNED_EQUALIZER_SLIDER_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), UI_TYPE_SKINNED_EQUALIZER_SLIDER, UiSkinnedEqualizerSliderPrivate))
@@ -305,7 +309,7 @@ static gboolean ui_skinned_equalizer_slider_button_press(GtkWidget *widget, GdkE
 
             ui_skinned_equalizer_slider_set_mainwin_text(es);
 
-            if (GTK_WIDGET_DRAWABLE (widget))
+            if (widget_really_drawable (widget))
                 ui_skinned_equalizer_slider_expose (widget, 0);
         }
     }
@@ -320,7 +324,7 @@ static gboolean ui_skinned_equalizer_slider_button_release(GtkWidget *widget, Gd
         priv->pressed = FALSE;
         mainwin_release_info_text();
 
-        if (GTK_WIDGET_DRAWABLE (widget))
+        if (widget_really_drawable (widget))
             ui_skinned_equalizer_slider_expose (widget, 0);
     }
     return TRUE;
@@ -350,7 +354,7 @@ static gboolean ui_skinned_equalizer_slider_motion_notify(GtkWidget *widget, Gdk
         ui_skinned_equalizer_slider_set_mainwin_text(es);
         equalizerwin_eq_changed();
 
-        if (GTK_WIDGET_DRAWABLE (widget))
+        if (widget_really_drawable (widget))
             ui_skinned_equalizer_slider_expose (widget, 0);
     }
 
@@ -378,7 +382,7 @@ static gboolean ui_skinned_equalizer_slider_scroll(GtkWidget *widget, GdkEventSc
     priv->value = ((gfloat) (25 - priv->position) * EQUALIZER_MAX_GAIN / 25.0 );
     equalizerwin_eq_changed();
 
-    if (GTK_WIDGET_DRAWABLE (widget))
+    if (widget_really_drawable (widget))
         ui_skinned_equalizer_slider_expose (widget, 0);
 
     return TRUE;
@@ -393,7 +397,7 @@ static void ui_skinned_equalizer_slider_toggle_scaled(UiSkinnedEqualizerSlider *
     gtk_widget_set_size_request(widget, priv->width*(priv->scaled ? config.scale_factor : 1),
     priv->height*(priv->scaled ? config.scale_factor : 1));
 
-    if (GTK_WIDGET_DRAWABLE (widget))
+    if (widget_really_drawable (widget))
         ui_skinned_equalizer_slider_expose (widget, 0);
 }
 
@@ -416,7 +420,7 @@ void ui_skinned_equalizer_slider_set_position(GtkWidget *widget, gfloat pos) {
     if (priv->position >= 24 && priv->position <= 26)
         priv->position = 25;
 
-    if (GTK_WIDGET_DRAWABLE (widget))
+    if (widget_really_drawable (widget))
         ui_skinned_equalizer_slider_expose (widget, 0);
 }
 
@@ -428,11 +432,9 @@ gfloat ui_skinned_equalizer_slider_get_position(GtkWidget *widget) {
 
 void ui_skinned_equalizer_slider_set_mainwin_text(UiSkinnedEqualizerSlider * es) {
     gint band = 0;
-    const gchar *bandname[11] = { N_("PREAMP"), N_("60HZ"), N_("170HZ"),
-        N_("310HZ"), N_("600HZ"), N_("1KHZ"),
-        N_("3KHZ"), N_("6KHZ"), N_("12KHZ"),
-        N_("14KHZ"), N_("16KHZ")
-    };
+    const gchar * const bandname[11] = {N_("Preamp"), N_("31 Hz"), N_("63 Hz"),
+     N_("125 Hz"), N_("250 Hz"), N_("500 Hz"), N_("1 kHz"), N_("2 kHz"),
+     N_("4 kHz"), N_("8 kHz"), N_("16 kHz")};
     gchar *tmp;
 
     if (es->x > 21)
