@@ -24,11 +24,13 @@
  * Audacious or using our public API to be a derived work.
  */
 
+#include <string.h>
+
+#include <libaudcore/audstrings.h>
+
 #include "ui_skinned_textbox.h"
 #include "skins_cfg.h"
 #include "plugin.h"
-#include <string.h>
-
 #include "util.h"
 
 #define UI_SKINNED_TEXTBOX_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), ui_skinned_textbox_get_type(), UiSkinnedTextboxPrivate))
@@ -51,7 +53,7 @@ struct _UiSkinnedTextboxPrivate {
     gboolean         scroll_back;
     gint             nominal_y, nominal_height;
     gint             scroll_timeout;
-    gint             font_ascent, font_descent;
+    gint crop;
     PangoFontDescription *font;
     gchar            *fontname;
     gchar            *pixbuf_text;
@@ -207,6 +209,13 @@ static void ui_skinned_textbox_destroy(GtkObject *object) {
         priv->scroll_timeout = 0;
     }
 
+    g_free (textbox->text);
+    textbox->text = NULL;
+    g_free (priv->pixbuf_text);
+    priv->pixbuf_text = NULL;
+    g_free (priv->fontname);
+    priv->fontname = NULL;
+
     if (GTK_OBJECT_CLASS (parent_class)->destroy)
         (* GTK_OBJECT_CLASS (parent_class)->destroy) (object);
 }
@@ -312,7 +321,7 @@ static void ui_skinned_textbox_size_allocate(GtkWidget *widget, GtkAllocation *a
             priv->offset = 0;
             gtk_widget_set_size_request(widget, textbox->width, textbox->height);
 
-            if (GTK_WIDGET_DRAWABLE (widget))
+            if (widget_really_drawable (widget))
                 ui_skinned_textbox_expose (widget, 0);
     }
 }
@@ -438,7 +447,7 @@ static gboolean ui_skinned_textbox_motion_notify(GtkWidget *widget, GdkEventMoti
             while (priv->offset > (priv->pixbuf_width - textbox->width))
                 priv->offset = (priv->pixbuf_width - textbox->width);
 
-            if (GTK_WIDGET_DRAWABLE (widget))
+            if (widget_really_drawable (widget))
                 ui_skinned_textbox_expose (widget, 0);
         }
     }
@@ -455,7 +464,7 @@ static void ui_skinned_textbox_toggle_scaled(UiSkinnedTextbox *textbox) {
     gtk_widget_set_size_request(widget, textbox->width*(priv->scaled ? config.scale_factor : 1 ),
     textbox->height*(priv->scaled ? config.scale_factor : 1 ));
 
-    if (GTK_WIDGET_DRAWABLE (widget))
+    if (widget_really_drawable (widget))
         ui_skinned_textbox_expose (widget, 0);
 }
 
@@ -508,21 +517,19 @@ void ui_skinned_textbox_set_xfont(GtkWidget *widget, gboolean use_xfont, const g
         return;
 
     priv->font = pango_font_description_from_string(fontname);
+    g_free (priv->fontname);
     priv->fontname = g_strdup(fontname);
 
     text_get_extents(fontname,
                      "AaBbCcDdEeFfGgHhIiJjKkLlMmNnOoPpQqRrSsTtUuVvWwXxYyZz ",
                      NULL, NULL, &ascent, &descent);
-    priv->font_ascent = ascent;
-    priv->font_descent = descent;
-
 
     if (priv->font == NULL)
         return;
 
-    textbox->height = priv->font_ascent; /* The real height of the text is
-     ascent - descent (descent is negative), but we cut off descent pixels from
-     the top to make it fit better. See textbox_generate_xfont_pixmap. */
+    textbox->height = ascent - descent;
+    priv->crop = textbox->height / 5;
+    textbox->height -= priv->crop;
 }
 
 void ui_skinned_textbox_set_text(GtkWidget *widget, const gchar *text) {
@@ -534,10 +541,10 @@ void ui_skinned_textbox_set_text(GtkWidget *widget, const gchar *text) {
     if (textbox->text)
         g_free(textbox->text);
 
-    textbox->text = aud_str_to_utf8(text);
+    textbox->text = str_to_utf8(text);
     priv->scroll_back = FALSE;
 
-    if (GTK_WIDGET_DRAWABLE (widget))
+    if (widget_really_drawable (widget))
         ui_skinned_textbox_expose (widget, 0);
 }
 
@@ -586,8 +593,7 @@ static void textbox_generate_xfont_pixmap(UiSkinnedTextbox *textbox, const gchar
     layout = gtk_widget_create_pango_layout(mainwin, pixmaptext);
     pango_layout_set_font_description(layout, priv->font);
 
-    gdk_draw_layout (pixmap, gc, 0, priv->font_descent, layout); /* See
-     explanation in ui_skinned_textbox_set_xfont. */
+    gdk_draw_layout (pixmap, gc, 0, - priv->crop, layout);
     g_object_unref(layout);
 
     g_object_unref(maskgc);
@@ -633,7 +639,7 @@ static gboolean textbox_scroll(gpointer data) {
                 priv->offset += 1;
             }
 
-            if (GTK_WIDGET_DRAWABLE (data))
+            if (widget_really_drawable (data))
                 ui_skinned_textbox_expose (data, 0);
         }
     }
@@ -772,7 +778,7 @@ void ui_skinned_textbox_set_scroll(GtkWidget *widget, gboolean scroll) {
 
         priv->offset = 0;
 
-        if (GTK_WIDGET_DRAWABLE (widget))
+        if (widget_really_drawable (widget))
             ui_skinned_textbox_expose (widget, 0);
     }
 }
