@@ -3,16 +3,11 @@
 
 #include <vorbis/vorbisfile.h>
 
-#include "audacious/vfs.h"
+#include <audacious/plugin.h>
 
 extern ov_callbacks vorbis_callbacks;
 
-void vorbis_configure(void);
-
-void vorbis_file_info_box(char *filename);
-
-char *convert_to_utf8(const char *string);
-char *convert_from_utf8(const char *string);
+gboolean vorbis_update_song_tuple (const Tuple * tuple, VFSFile * fd);
 
 typedef struct {
     gint http_buffer_size;
@@ -26,20 +21,10 @@ typedef struct {
     gchar *save_http_path;
     gboolean tag_override;
     gchar *tag_format;
-    gboolean use_anticlip;
-    gboolean use_replaygain;
-    gint replaygain_mode;
-    gboolean use_booster;
     gboolean title_encoding_enabled;
-    gchar *title_encoding;        
+    gchar *title_encoding;
 } vorbis_config_t;
 
-enum {
-    REPLAYGAIN_MODE_TRACK,
-    REPLAYGAIN_MODE_ALBUM,
-    REPLAYGAIN_MODE_LAST
-};
-
-#define         ENCODING_SEPARATOR      " ,:;|/"
+extern vorbis_config_t vorbis_cfg;
 
 #endif                          /* __VORBIS_H__ */
