@@ -70,8 +70,8 @@ gint
 vtx_is_our_fd (const gchar *filename, VFSFile *fp)
 {
   char buf[2];
-
-  vfs_fread (buf, 2, 1, fp);
+  if (vfs_fread(buf, 1, 2, fp) < 2)
+      return FALSE;
   return (!strncasecmp (buf, "ay", 2) || !strncasecmp (buf, "ym", 2));
 }
 
